@@ -8,7 +8,7 @@ class ColorHexModel(BaseModel):
     value: Color
 
     @validator("value")
-    def value_as_hex(cls, v):
+    def value_as_hex(v):
         return Color(v).as_hex()
 
 
