@@ -8,7 +8,7 @@ class HSLModel(BaseModel):
     value: Color
 
     @validator("value")
-    def value_as_hsl(cls, v):
+    def value_as_hsl(v):
         return Color(v).as_hsl()
 
 
