@@ -8,7 +8,7 @@ class IPv6Model(BaseModel):
     value: IPv6Address
 
     @validator("value")
-    def value_validate(cls, v):
+    def value_validate(v):
         return str(v)
 
 
