@@ -7,7 +7,7 @@ class NonEmptyStringModel(BaseModel):
     value: str
 
     @validator("value")
-    def value_non_empty_string(cls, v):
+    def value_non_empty_string(v):
         assert str(v), "value must be string"
         assert v != "", "value cannot be empty"
         return v
