@@ -7,7 +7,7 @@ class NonNegativeFloatModel(BaseModel):
     value: float
 
     @validator("value")
-    def value_greater_equal_zero(cls, v):
+    def value_greater_equal_zero(v):
         assert float(v), "value must be float"
         assert v >= 0, "value must be greater than or equal to zero"
         return v
