@@ -7,7 +7,7 @@ class NonPositiveIntModel(BaseModel):
     value: int
 
     @validator("value")
-    def value_greater_equal_zero(cls, v):
+    def value_greater_equal_zero(v):
         assert int(v), "value must be int"
         assert v <= 0, "value must be less than or equal to zero"
         return v
