@@ -8,7 +8,7 @@ class PhoneNumberModel(BaseModel):
     value: str
 
     @validator("value")
-    def value_phone_number(cls, v):
+    def value_phone_number(v):
         assert str(v), "value must be string"
         assert is_valid_number(parse(v, None)), "value must be a valid phone number"
         return v
